"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var expect = chai.expect;
var assert = chai.assert;
var childProcess = require("child_process");
var exec = childProcess.exec;
describe('index', function () {
    describe('CLI', function () {
        it('no parameters', function (done) {
            exec('node lib/index.js', function (error, stdout, stderr) {
                expect(stderr).to.contain('no command given!');
                done();
            });
        }).timeout(5000);
        ;
        it('missing file parameter', function (done) {
            exec('node lib/index.js validate', function (error, stdout, stderr) {
                expect(stderr).to.contain('missing required argument');
                done();
            });
        }).timeout(5000);
        ;
        it('validate simple yaml', function (done) {
            exec('node lib/index.js validate testData/valid/yaml/issue-28-custom-resource.yaml', function (error, stdout, stderr) {
                expect(stdout).to.contain('0 crit');
                done();
            });
        }).timeout(5000);
        it('validate parameter flag', function (done) {
            exec('node lib/index.js validate testData/valid/json/2.json --parameters InstanceType="t1.micro"', function (error, stdout, stderr) {
                expect(stdout).to.contain('0 crit');
                done();
            });
        }).timeout(5000);
        it('validate pseudo flag', function (done) {
            exec('node lib/index.js validate testData/valid/yaml/pseudo-parameters.yaml ' +
                '--pseudo AWS::Region=us-east-1,AWS::AccountId=000000000000', function (error, stdout, stderr) {
                expect(stdout).to.contain('0 crit');
                done();
            });
        }).timeout(5000);
        it('validate pseudo + parameter flag', function (done) {
            exec('node lib/index.js validate testData/valid/yaml/pseudo-w-parameter.yaml ' +
                '--parameters MyInput=abcd --pseudo AWS::Region=us-east-1', function (error, stdout, stderr) {
                expect(stdout).to.contain('0 crit');
                done();
            });
        }).timeout(5000);
        it('invalid pseudo flag throws 2 critical error', function (done) {
            exec('node lib/index.js validate testData/valid/yaml/pseudo-parameters.yaml ' +
                '--pseudo AWS::Region=us-east-1,Something=000000000000', function (error, stdout, stderr) {
                expect(stdout).to.contain('2 crit');
                done();
            });
        }).timeout(5000);
        it('guess-parameters should explicitely opt in to parameter mocking', function (done) {
            exec('node lib/index.js validate testData/valid/yaml/no-guess-parameters.yaml --guess-parameters', function (error, stdout, stderr) {
                expect(stdout).to.contain('0 crit');
                done();
            });
        }).timeout(5000);
        it('no-guess-parameters throws errors if we leave out parameters', function (done) {
            exec('node lib/index.js validate testData/valid/yaml/no-guess-parameters.yaml --no-guess-parameters', function (error, stdout, stderr) {
                expect(stdout).to.contain('2 crit');
                expect(stdout).to.contain('Value for parameter was not provided');
                done();
            });
        }).timeout(5000);
        it('only-guess-parameters should allow opting in to parameter mocking', function (done) {
            exec('node lib/index.js validate testData/valid/yaml/no-guess-parameters.yaml --only-guess-parameters Param1', function (error, stdout, stderr) {
                expect(stdout).to.contain('1 crit');
                expect(stdout).to.contain('Value for parameter was not provided');
                done();
            });
        }).timeout(5000);
        it('only-guess-parameters should allow opting in to parameter mocking with multiple params', function (done) {
            exec('node lib/index.js validate testData/valid/yaml/no-guess-parameters.yaml --only-guess-parameters Param1,Param2', function (error, stdout, stderr) {
                expect(stdout).to.contain('0 crit');
                done();
            });
        }).timeout(5000);
        it('handle validation exceptions - non-verbose', function (done) {
            exec('node lib/index.js validate testData/invalid/yaml/invalid_yaml.yaml', function (error, stdout, stderr) {
                expect(error).to.have.property('code', 1);
                expect(stdout).to.contain('Unable to parse template! Use --verbose for more information.');
                expect(stderr).to.be.empty;
                done();
            });
        }).timeout(5000);
        it('handle validation exceptions - verbose', function (done) {
            exec('node lib/index.js validate testData/invalid/yaml/invalid_yaml.yaml --verbose', function (error, stdout, stderr) {
                expect(error).to.have.property('code', 1);
                expect(stdout).to.contain('Unable to parse template! Use --verbose for more information.');
                expect(stderr).to.contain('Error: Could not determine file type');
                done();
            });
        }).timeout(5000);
    });
});
//# sourceMappingURL=indexTest.js.map